@@ -2,8 +2,9 @@
 This file define chuy as a module.
 """
 
-from .core import exec_commands, get_config, main
+from .core import main
 
+# Package Data
 __version__ = "0.1.1"
 __authors__ = ["Eliaz Bobadilla <eliaz.bobadilladev@gmail.com>"]
 __author_email__ = "eliaz.bobadilladev@gmail.com"
